Yahoo - velruse.providers.yahoo — Velruse 1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Velruse 1.1 documentation »
- Provider Documentation »

# Yahoo - `velruse.providers.yahoo`

Like Google, Yahoo offers either plain OpenID for authentication or an OpenID+OAuth hybrid authentication granting access to Yahoo applications while authenticating a user for sign-on. Unlike Google, Yahoo requires the application to register in advance the scope of the API token to issue. Using the Yahoo OAuth requires registration of a Yahoo application.

Yahoo Developer Links:

- Yahoo Developer Projects Page (Create new apps here)
- Yahoo OpenID + OAuth Guide

## Settings

Like Google, the Yahoo provider requires that an OpenID provider configuration be present in your configuration file in order to provide the `Realm` and `Store` configuration values.

Warning

The `Realm` must point to a valid DNS name that is resolvable by Yahoo’s authentication servers. If this is not the case, Yahoo will consider the authentication invalid and display an error message.

The following parameters are only required if using the OAuth hybrid:

`consumer_key`
  Yahoo consumer key
`consumer_secret`
  Yahoo secret

## POST Parameters

Since Yahoo declares the scope of OAuth with the application, you only need to provide the oauth POST parameter if you want OAuth to take place (which requires a Yahoo application to be created, and configured in the YAML as shown above).

Complete Example:

    <form action="/velruse/yahoo/login" method="post">
        <input type="hidden" name="oauth" value="true" />
        <input type="submit" value="Login with Yahoo" />
    </form>

## Pyramid API

class `YahooAuthenticationComplete`(profile=None, credentials=None, provider_name=None, provider_type=None)

  Bases: `velruse.providers.openid.OpenIDAuthenticationComplete`

  Yahoo auth complete

`includeme`(config)

`add_yahoo_login`(config, realm=None, storage=None, consumer_key=None, consumer_secret=None, login_path='/login/yahoo', callback_path='/login/yahoo/callback', name='yahoo')

  Add a Yahoo login provider to the application.

  OpenID parameters: realm, storage

  OAuth parameters: consumer_key, consumer_secret

### Navigation

- index
- modules |
- next |
- previous |
- Velruse 1.1 documentation »
- Provider Documentation »